```{include} ../../README.md

```

## Feedback

If you encounter any errors or problems with **intake-thredds**, please open an issue at the GitHub [main repository](http://github.com/NCAR/intake-thredds).

## Documentation Contents

```{toctree}
---
maxdepth: 2
---
installation.md
tutorial.ipynb
api.md
contributing.md
changelog.md
```
